@@ -22,6 +22,7 @@
 #include <fcntl.h>
 #include <ftw.h>
 #include <errno.h>
+#include <pwd.h>
 
 int arg_quiet = 0;
 static int arg_follow_link = 0;
@@ -40,6 +41,11 @@ static void copy_file(const char *srcname, const char *destname, mode_t mode, ui
 	assert(destname);
 	mode &= 07777;
 
+	// don't copy the file if it is already there
+	struct stat s;
+	if (stat(destname, &s) == 0)
+		return;
+
 	// open source
 	int src = open(srcname, O_RDONLY);
 	if (src < 0) {
@@ -112,10 +118,18 @@ void copy_link(const char *target, const char *linkpath, mode_t mode, uid_t uid,
 	(void) mode;
 	(void) uid;
 	(void) gid;
+
+	// if the link is already there, don't create it
+	struct stat s;
+	if (stat(linkpath, &s) == 0)
+	       return;
+
 	char *rp = realpath(target, NULL);
 	if (rp) {
-		if (symlink(rp, linkpath) == -1)
+		if (symlink(rp, linkpath) == -1) {
+			free(rp);
 			goto errout;
+		}
 		free(rp);
 	}
 	else
@@ -128,6 +142,7 @@ errout:
 }
 
 
+
 static int first = 1;
 static int fs_copydir(const char *infname, const struct stat *st, int ftype, struct FTW *sftw) {
 	(void) st;
@@ -199,10 +214,22 @@ static char *check(const char *src) {
 	if (!rsrc || stat(rsrc, &s) == -1)
 		goto errexit;
 
-	// check uid
+	// on systems with systemd-resolved installed /etc/resolve.conf is a symlink to
+	//    /run/systemd/resolve/resolv.conf; this file is owned by systemd-resolve user
 	// checking gid will fail for files with a larger group such as /usr/bin/mutt_dotlock
-	if (s.st_uid != getuid()/* || s.st_gid != getgid()*/)
-		goto errexit;
+	uid_t user = getuid();
+	if (user == 0 && strncmp(rsrc, "/run/systemd/resolve/", 21) == 0) {
+		// check user systemd-resolve
+		struct passwd *p = getpwnam("systemd-resolve");
+		if (!p)
+			goto errexit;
+		if (s.st_uid != user && s.st_uid != p->pw_uid)
+			goto errexit;
+	}
+	else {
+		if (s.st_uid != user)
+			goto errexit;
+	}
 
 	// dir, link, regular file
 	if (S_ISDIR(s.st_mode) || S_ISREG(s.st_mode) || S_ISLNK(s.st_mode))
