@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2016 Firejail Authors
+ * Copyright (C) 2014-2017 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -28,7 +28,7 @@
 
 static int cmdline_length(int argc, char **argv, int index) {
 	assert(index != -1);
-	
+
 	unsigned i,j;
 	int len = 0;
 	unsigned argcnt = argc - index;
@@ -91,7 +91,7 @@ static void quote_cmdline(char *command_line, char *window_title, int len, int a
 				if (j > 0 && argv[i + index][j-1] == '\'') {
 					ptr1--;
 					sprintf(ptr1, "\'\"");
-				} 
+				}
 				// this first in series
 				else
 				{
@@ -151,9 +151,61 @@ void build_cmdline(char **command_line, char **window_title, int argc, char **ar
 	*window_title = malloc(len + 1);
 	if (!*window_title)
 			errExit("malloc");
-	
+
 	quote_cmdline(*command_line, *window_title, len, argc, argv, index);
 
+	if (arg_debug)
+		printf("Building quoted command line: %s\n", *command_line);
+
 	assert(*command_line);
 	assert(*window_title);
 }
+
+void build_appimage_cmdline(char **command_line, char **window_title, int argc, char **argv, int index, char *apprun_path) {
+	// index == -1 could happen if we have --shell=none and no program was specified
+	// the program should exit with an error before entering this function
+	assert(index != -1);
+
+	if (arg_debug)
+		printf("Building AppImage command line: %s\n", *command_line);
+
+
+	int len1 = cmdline_length(argc, argv, index);  // length of argv w/o changes
+	int len2 = cmdline_length(1, &argv[index], 0); // apptest.AppImage
+	int len3 = cmdline_length(1, &apprun_path, 0); // /run/firejail/appimage/.appimage-23304/AppRun
+	int len4 = (len1 - len2 + len3) + 1;           // apptest.AppImage is replaced by /path/to/AppRun
+
+	if (len4 > ARG_MAX) {
+		errno = E2BIG;
+		errExit("cmdline_length");
+	}
+
+	// save created apprun in cfg.command_line
+	char *tmp1 = strdup(*command_line);
+	if (!tmp1)
+		errExit("strdup");
+
+	// TODO: deal with extra allocated memory.
+	char *command_line_tmp = malloc(len1 + len3 + 1);
+	if (!command_line_tmp)
+			errExit("malloc");
+	*window_title = malloc(len1 + len3 + 1);
+	if (!*window_title)
+			errExit("malloc");
+
+	// run default quote_cmdline
+	quote_cmdline(command_line_tmp, *window_title, len1, argc, argv, index);
+
+	assert(command_line_tmp);
+	assert(*window_title);
+
+	// 'fix' command_line now
+	if (asprintf(command_line, "'%s' %s", tmp1, command_line_tmp + len2) == -1)
+		errExit("asprintf");
+
+	if (arg_debug)
+		printf("AppImage quoted command line: %s\n", *command_line);
+
+	// free strdup
+	free(tmp1);
+}
