@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2016 Firejail Authors
+ * Copyright (C) 2014-2017 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -48,7 +48,7 @@ static void release_all(void) {
 	}
 	dirlist = NULL;
 }
-	
+
 static void build_list(const char *srcdir) {
 	// extract current /var/log directory data
 	struct dirent *dir;
@@ -65,10 +65,9 @@ static void build_list(const char *srcdir) {
 			struct stat s;
 			char *name;
 			if (asprintf(&name, "%s/%s", srcdir, dir->d_name) == -1)
-				continue;
-			if (stat(name, &s) == -1)
-				continue;
-			if (S_ISLNK(s.st_mode)) {
+				errExit("asprintf");
+			if (stat(name, &s) == -1 ||
+			    S_ISLNK(s.st_mode)) {
 				free(name);
 				continue;
 			}
@@ -78,7 +77,7 @@ static void build_list(const char *srcdir) {
 //				s.st_uid,
 //				s.st_gid,
 //				dir->d_name);
-			
+
 			DirData *ptr = malloc(sizeof(DirData));
 			if (ptr == NULL)
 				errExit("malloc");
@@ -88,8 +87,8 @@ static void build_list(const char *srcdir) {
 			ptr->st_uid = s.st_uid;
 			ptr->st_gid = s.st_gid;
 			ptr->next = dirlist;
-			dirlist = ptr;		
-		}			
+			dirlist = ptr;
+		}
 	}
 	closedir(d);
 }
@@ -98,18 +97,16 @@ static void build_dirs(void) {
 	// create directories under /var/log
 	DirData *ptr = dirlist;
 	while (ptr) {
-		if (mkdir(ptr->name, ptr->st_mode))
-			errExit("mkdir");
-		if (chown(ptr->name, ptr->st_uid, ptr->st_gid))
-			errExit("chown");
+		mkdir_attr(ptr->name, ptr->st_mode, ptr->st_uid, ptr->st_gid);
 		fs_logger2("mkdir", ptr->name);
 		ptr = ptr->next;
 	}
 }
-	
+
 void fs_var_log(void) {
 	build_list("/var/log");
-	
+
+	// note: /var/log is not created here, if it does not exist, this section fails.
 	// create /var/log if it doesn't exit
 	if (is_dir("/var/log")) {
 		// extract group id for /var/log/wtmp
@@ -117,39 +114,41 @@ void fs_var_log(void) {
 		gid_t wtmp_group = 0;
 		if (stat("/var/log/wtmp", &s) == 0)
 			wtmp_group = s.st_gid;
-		
+
 		// mount a tmpfs on top of /var/log
 		if (arg_debug)
 			printf("Mounting tmpfs on /var/log\n");
 		if (mount("tmpfs", "/var/log", "tmpfs", MS_NOSUID | MS_NOEXEC | MS_NODEV | MS_STRICTATIME | MS_REC,  "mode=755,gid=0") < 0)
 			errExit("mounting /var/log");
 		fs_logger("tmpfs /var/log");
-		
+
 		build_dirs();
 		release_all();
-		
+
 		// create an empty /var/log/wtmp file
 		/* coverity[toctou] */
 		FILE *fp = fopen("/var/log/wtmp", "w");
-		SET_PERMS_STREAM(fp, 0, wtmp_group, S_IRUSR | S_IWRITE | S_IRGRP | S_IWGRP | S_IROTH);
-		if (fp)
+		if (fp) {
+			SET_PERMS_STREAM(fp, 0, wtmp_group, S_IRUSR | S_IWRITE | S_IRGRP | S_IWGRP | S_IROTH);
 			fclose(fp);
+		}
 		fs_logger("touch /var/log/wtmp");
-			
+
 		// create an empty /var/log/btmp file
 		fp = fopen("/var/log/btmp", "w");
-		SET_PERMS_STREAM(fp, 0, wtmp_group, S_IRUSR | S_IWRITE | S_IRGRP | S_IWGRP);
-		if (fp)
+		if (fp) {
+			SET_PERMS_STREAM(fp, 0, wtmp_group, S_IRUSR | S_IWRITE | S_IRGRP | S_IWGRP);
 			fclose(fp);
+		}
 		fs_logger("touch /var/log/btmp");
 	}
 	else
-		fprintf(stderr, "Warning: cannot mount tmpfs on top of /var/log\n");
+		fwarning("cannot hide /var/log directory\n");
 }
 
 void fs_var_lib(void) {
 	struct stat s;
-	
+
 	// ISC DHCP multiserver
 	if (stat("/var/lib/dhcp", &s) == 0) {
 		if (arg_debug)
@@ -157,10 +156,10 @@ void fs_var_lib(void) {
 		if (mount("tmpfs", "/var/lib/dhcp", "tmpfs", MS_NOSUID |  MS_NOEXEC | MS_NODEV | MS_STRICTATIME | MS_REC,  "mode=755,gid=0") < 0)
 			errExit("mounting /var/lib/dhcp");
 		fs_logger("tmpfs /var/lib/dhcp");
-			
+
 		// isc dhcp server requires a /var/lib/dhcp/dhcpd.leases file
 		FILE *fp = fopen("/var/lib/dhcp/dhcpd.leases", "w");
-		
+
 		if (fp) {
 			fprintf(fp, "\n");
 			SET_PERMS_STREAM(fp, 0, 0, S_IRUSR|S_IWUSR|S_IRGRP|S_IROTH);
@@ -176,7 +175,7 @@ void fs_var_lib(void) {
 		if (mount("tmpfs", "/var/lib/nginx", "tmpfs", MS_NOSUID | MS_NOEXEC | MS_NODEV | MS_STRICTATIME | MS_REC,  "mode=755,gid=0") < 0)
 			errExit("mounting /var/lib/nginx");
 		fs_logger("tmpfs /var/lib/nginx");
-	}			
+	}
 
 	// net-snmp multiserver
 	if (stat("/var/lib/snmp", &s) == 0) {
@@ -185,7 +184,7 @@ void fs_var_lib(void) {
 		if (mount("tmpfs", "/var/lib/snmp", "tmpfs", MS_NOSUID | MS_NOEXEC | MS_NODEV | MS_STRICTATIME | MS_REC,  "mode=755,gid=0") < 0)
 			errExit("mounting /var/lib/snmp");
 		fs_logger("tmpfs /var/lib/snmp");
-	}			
+	}
 
 	// this is where sudo remembers its state
 	if (stat("/var/lib/sudo", &s) == 0) {
@@ -194,7 +193,7 @@ void fs_var_lib(void) {
 		if (mount("tmpfs", "/var/lib/sudo", "tmpfs", MS_NOSUID | MS_NOEXEC | MS_NODEV | MS_STRICTATIME | MS_REC,  "mode=755,gid=0") < 0)
 			errExit("mounting /var/lib/sudo");
 		fs_logger("tmpfs /var/lib/sudo");
-	}			
+	}
 }
 
 void fs_var_cache(void) {
@@ -206,7 +205,7 @@ void fs_var_cache(void) {
 		if (mount("tmpfs", "/var/cache/apache2", "tmpfs", MS_NOSUID | MS_NOEXEC | MS_NODEV | MS_STRICTATIME | MS_REC,  "mode=755,gid=0") < 0)
 			errExit("mounting /var/cache/apache2");
 		fs_logger("tmpfs /var/cache/apache2");
-	}			
+	}
 
 	if (stat("/var/cache/lighttpd", &s) == 0) {
 		if (arg_debug)
@@ -222,21 +221,13 @@ void fs_var_cache(void) {
 			uid = p->pw_uid;
 			gid = p->pw_gid;
 		}
-		
-		int rv = mkdir("/var/cache/lighttpd/compress", 0755);
-		if (rv == -1)
-			errExit("mkdir");
-		if (chown("/var/cache/lighttpd/compress", uid, gid) < 0)
-			errExit("chown");
+
+		mkdir_attr("/var/cache/lighttpd/compress", 0755, uid, gid);
 		fs_logger("mkdir /var/cache/lighttpd/compress");
 
-		rv = mkdir("/var/cache/lighttpd/uploads", 0755);
-		if (rv == -1)
-			errExit("mkdir");
-		if (chown("/var/cache/lighttpd/uploads", uid, gid) < 0)
-			errExit("chown");
+		mkdir_attr("/var/cache/lighttpd/uploads", 0755, uid, gid);
 		fs_logger("/var/cache/lighttpd/uploads");
-	}			
+	}
 }
 
 void dbg_test_dir(const char *dir) {
@@ -268,11 +259,7 @@ void fs_var_lock(void) {
 		if (lnk) {
 			if (!is_dir(lnk)) {
 				// create directory
-				if (mkdir(lnk, S_IRWXU|S_IRWXG|S_IRWXO))
-					errExit("mkdir");
-				if (chmod(lnk, S_IRWXU|S_IRWXG|S_IRWXO))
-					errExit("chmod");
-				ASSERT_PERMS(lnk, 0, 0, S_IRWXU|S_IRWXG|S_IRWXO);
+				mkdir_attr(lnk, S_IRWXU|S_IRWXG|S_IRWXO, 0, 0);
 			}
 			if (arg_debug)
 				printf("Mounting tmpfs on %s on behalf of /var/lock\n", lnk);
@@ -282,7 +269,7 @@ void fs_var_lock(void) {
 			fs_logger("tmpfs /var/lock");
 		}
 		else {
-			fprintf(stderr, "Warning: /var/lock not mounted\n");
+			fwarning("/var/lock not mounted\n");
 			dbg_test_dir("/var/lock");
 		}
 	}
@@ -300,7 +287,7 @@ void fs_var_tmp(void) {
 		}
 	}
 	else {
-		fprintf(stderr, "Warning: /var/tmp not mounted\n");
+		fwarning("/var/tmp not mounted\n");
 		dbg_test_dir("/var/tmp");
 	}
 }
@@ -313,13 +300,10 @@ void fs_var_utmp(void) {
 	if (stat(UTMP_FILE, &s) == 0)
 		utmp_group = s.st_gid;
 	else {
-		fprintf(stderr, "Warning: cannot find /var/run/utmp\n");
+		fwarning("cannot find /var/run/utmp\n");
 		return;
 	}
 
-	// create /run/firejail/mnt directory
-	fs_build_mnt_dir();
-	
 	// create a new utmp file
 	if (arg_debug)
 		printf("Create the new utmp file\n");
@@ -328,7 +312,7 @@ void fs_var_utmp(void) {
 	FILE *fp = fopen(RUN_UTMP_FILE, "w");
 	if (!fp)
 		errExit("fopen");
-		
+
 	// read current utmp
 	struct utmp *u;
 	struct utmp u_boot;
@@ -340,12 +324,13 @@ void fs_var_utmp(void) {
 		}
 	}
 	endutent();
-			
+
 	// save new utmp file
-	fwrite(&u_boot, sizeof(u_boot), 1, fp);
+	int rv = fwrite(&u_boot, sizeof(u_boot), 1, fp);
+	(void) rv;
 	SET_PERMS_STREAM(fp, 0, utmp_group, S_IRUSR | S_IWRITE | S_IRGRP | S_IWGRP | S_IROTH);
 	fclose(fp);
-	
+
 	// mount the new utmp file
 	if (arg_debug)
 		printf("Mount the new utmp file\n");
