@@ -24,6 +24,18 @@
 void set_rlimits(void) {
 	// resource limits
 	struct rlimit rl;
+	if (arg_rlimit_cpu) {
+		rl.rlim_cur = (rlim_t) cfg.rlimit_cpu;
+		rl.rlim_max = (rlim_t) cfg.rlimit_cpu;
+#ifdef HAVE_GCOV
+		__gcov_dump();
+#endif
+		if (setrlimit(RLIMIT_CPU, &rl) == -1)
+			errExit("setrlimit");
+		if (arg_debug)
+			printf("Config rlimit: max cpu time %llu\n", cfg.rlimit_cpu);
+	}
+
 	if (arg_rlimit_nofile) {
 		rl.rlim_cur = (rlim_t) cfg.rlimit_nofile;
 		rl.rlim_max = (rlim_t) cfg.rlimit_nofile;
@@ -71,4 +83,16 @@ void set_rlimits(void) {
 		if (arg_debug)
 			printf("Config rlimit: maximum number of signals pending %llu\n", cfg.rlimit_sigpending);
 	}
+
+	if (arg_rlimit_as) {
+		rl.rlim_cur = (rlim_t) cfg.rlimit_as;
+		rl.rlim_max = (rlim_t) cfg.rlimit_as;
+#ifdef HAVE_GCOV
+		__gcov_dump();
+#endif
+		if (setrlimit(RLIMIT_AS, &rl) == -1)
+			errExit("setrlimit");
+		if (arg_debug)
+			printf("Config rlimit: maximum virtual memory %llu\n", cfg.rlimit_as);
+	}
 }
