@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2016 Firejail Authors
+ * Copyright (C) 2014-2017 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -24,7 +24,7 @@
 
 void run_symlink(int argc, char **argv) {
 	EUID_ASSERT();
-	
+
 	char *program = strrchr(argv[0], '/');
 	if (program)
 		program += 1;
@@ -40,7 +40,7 @@ void run_symlink(int argc, char **argv) {
 		fprintf(stderr, "Error: PATH environment variable not set\n");
 		exit(1);
 	}
-	
+
 	char *path = strdup(p);
 	if (!path)
 		errExit("strdup");
@@ -59,6 +59,7 @@ void run_symlink(int argc, char **argv) {
 
 		struct stat s;
 		if (stat(name, &s) == 0) {
+			/* coverity[toctou] */
 			char* rp = realpath(name, NULL);
 			if (!rp)
 				errExit("realpath");
@@ -85,12 +86,6 @@ void run_symlink(int argc, char **argv) {
 
 
 	// start the argv[0] program in a new sandbox
-	char *firejail;
-	if (asprintf(&firejail, "%s/bin/firejail", PREFIX) == -1)
-		errExit("asprintf");
-
-	printf("Redirecting symlink to %s\n", program);
-
 	// drop privileges
 	if (setgid(getgid()) < 0)
 		errExit("setgid/getgid");
@@ -99,14 +94,15 @@ void run_symlink(int argc, char **argv) {
 
 	// run command
 	char *a[3 + argc];
-	a[0] = firejail;
+	a[0] =PATH_FIREJAIL;
 	a[1] = program;
 	int i;
 	for (i = 0; i < (argc - 1); i++) {
 		a[i + 2] = argv[i + 1];
 	}
 	a[i + 2] = NULL;
-	execvp(a[0], a); 
+	assert(getenv("LD_PRELOAD") == NULL);
+	execvp(a[0], a);
 
 	perror("execvp");
 	exit(1);
