@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2016 netblue30 (netblue30@yahoo.com)
+ * Copyright (C) 2014-2017 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -20,16 +20,12 @@
 #include "firemon.h"
 
 void list(void) {
-	if (getuid() == 0)
-		firemon_drop_privs();
-	
 	pid_read(0);	// include all processes
-	
+
 	// print processes
 	int i;
 	for (i = 0; i < max_pids; i++) {
 		if (pids[i].level == 1)
-			pid_print_list(i, 0);
+			pid_print_list(i, arg_nowrap);
 	}
 }
-
