@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2016 netblue30 (netblue30@yahoo.com)
+ * Copyright (C) 2014-2017 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -40,14 +40,12 @@ static int pid_is_firejail(pid_t pid) {
 	printf("%s: %d, pid %d\n", __FUNCTION__, __LINE__, pid);
 #endif
 	uid_t rv = 0;
-	
+
 	// open /proc/self/comm
 	char *file;
-	if (asprintf(&file, "/proc/%u/comm", pid) == -1) {
-		perror("asprintf");
-		exit(1);
-	}
-	
+	if (asprintf(&file, "/proc/%u/comm", pid) == -1)
+		errExit("asprintf");
+
 	FILE *fp = fopen(file, "r");
 	if (!fp) {
 		free(file);
@@ -60,7 +58,7 @@ static int pid_is_firejail(pid_t pid) {
 		if (strncmp(buf, "firejail", 8) == 0)
 			rv = 1;
 	}
-	
+
 #ifdef DEBUG_PRCTL
 	printf("%s: %d, comm %s, rv %d\n", __FUNCTION__, __LINE__, buf, rv);
 #endif
@@ -72,28 +70,36 @@ static int pid_is_firejail(pid_t pid) {
 			errExit("asprintf");
 		if ((fd = open(fname, O_RDONLY)) < 0) {
 			free(fname);
-			rv = 0;
+#ifdef DEBUG_PRCTL
+			printf("%s: %d, comm %s, rv %d\n", __FUNCTION__, __LINE__, buf, rv);
+#endif
 			goto doexit;
 		}
 		free(fname);
-	
+
 		// read file
 #define BUFLEN 4096
 		unsigned char buffer[BUFLEN];
 		ssize_t len;
 		if ((len = read(fd, buffer, sizeof(buffer) - 1)) <= 0) {
 			close(fd);
-			rv = 0;
+#ifdef DEBUG_PRCTL
+			printf("%s: %d, comm %s, rv %d\n", __FUNCTION__, __LINE__, buf, rv);
+#endif
 			goto doexit;
 		}
 		buffer[len] = '\0';
 		close(fd);
-	
+
 		// list of firejail arguments that don't trigger sandbox creation
-		// the initial -- is not included 
-		char *firejail_args = "ls list tree x11 help version top netstats debug-syscalls debug-errnos debug-protocols "
-			"protocol.print debug.caps shutdown bandwidth caps.print cpu.print debug-caps fs.print get overlay-clean ";
-		
+		// the initial -- is not included
+		char *exclude_args[] = {
+			"ls", "list", "tree", "x11", "help", "version", "top", "netstats", "debug-syscalls",
+			"debug-errnos", "debug-protocols", "protocol.print",  "debug.caps",
+			"shutdown", "bandwidth", "caps.print", "cpu.print", "debug-caps",
+			"fs.print", "get", "overlay-clean", NULL
+		};
+
 		int i;
 		char *start;
 		int first = 1;
@@ -107,21 +113,31 @@ static int pid_is_firejail(pid_t pid) {
 			}
 			if (strncmp(start, "--", 2) != 0)
 				break;
-			
+			start += 2;
+
 			// clan starting with =
-			char *ptr = strchr(start + 2, '=');
+			char *ptr = strchr(start, '=');
 			if (ptr)
 				*ptr = '\0';
-			
-			if (strstr(firejail_args, start + 2)) {
-				rv = 0;
-				break;
+
+			// look into exclude list
+			int j = 0;
+			while (exclude_args[j] != NULL) {
+				if (strcmp(start, exclude_args[j]) == 0) {
+					rv = 0;
+#ifdef DEBUG_PRCTL
+printf("start=#%s#,  ptr=#%s#, flip rv %d\n", start, ptr, rv);
+#endif
+					break;
+				}
+				j++;
 			}
+
 			start = (char *) buffer + i + 1;
 		}
 	}
 
-doexit:	
+doexit:
 	fclose(fp);
 	free(file);
 #ifdef DEBUG_PRCTL
@@ -134,10 +150,8 @@ doexit:
 static int procevent_netlink_setup(void) {
 	// open socket for process event connector
 	int sock;
-	if ((sock = socket(PF_NETLINK, SOCK_DGRAM, NETLINK_CONNECTOR)) < 0) {
-		fprintf(stderr, "Error: cannot open netlink socket\n");
-		exit(1);
-	}
+	if ((sock = socket(PF_NETLINK, SOCK_DGRAM, NETLINK_CONNECTOR)) < 0)
+		goto errexit;
 
 	// bind socket
 	struct sockaddr_nl addr;
@@ -145,10 +159,8 @@ static int procevent_netlink_setup(void) {
 	addr.nl_pid = getpid();
 	addr.nl_family = AF_NETLINK;
 	addr.nl_groups = CN_IDX_PROC;
-	if (bind(sock, (struct sockaddr *)&addr, sizeof(addr)) < 0) {
-		fprintf(stderr, "Error: cannot bind to netlink socket\n");
-		exit(1);
-	}
+	if (bind(sock, (struct sockaddr *)&addr, sizeof(addr)) < 0)
+		goto errexit;
 
 	// send monitoring message
 	struct nlmsghdr nlmsghdr;
@@ -173,12 +185,13 @@ static int procevent_netlink_setup(void) {
 	iov[2].iov_base = &op;
 	iov[2].iov_len = sizeof(op);
 
-	if (writev(sock, iov, 3) == -1) {
-		fprintf(stderr, "Error: cannot write to netlink socket\n");
-		exit(1);
-	}
-	
+	if (writev(sock, iov, 3) == -1)
+		goto errexit;
+
 	return sock;
+errexit:
+	fprintf(stderr, "Error: netlink socket problem\n");
+	exit(1);
 }
 
 
@@ -192,29 +205,33 @@ static int procevent_monitor(const int sock, pid_t mypid) {
 	tv.tv_usec = 0;
 
 	while (1) {
-#define BUFFSIZE 4096 
+#ifdef HAVE_GCOV
+		__gcov_flush();
+#endif
+
+#define BUFFSIZE 4096
 		char __attribute__ ((aligned(NLMSG_ALIGNTO)))buf[BUFFSIZE];
-		
+
 		fd_set readfds;
 		int max;
 		FD_ZERO(&readfds);
 		FD_SET(sock, &readfds);
 		max = sock;
 		max++;
-		
+
 		int rv = select(max, &readfds, NULL, NULL, &tv);
 		if (rv == -1) {
 			fprintf(stderr, "recv: %s\n", strerror(errno));
 			return -1;
 		}
-		
+
 		// timeout
 		if (rv == 0) {
 			tv.tv_sec = 30;
 			tv.tv_usec = 0;
 			continue;
 		}
-		
+
 
 		if ((len = recv(sock, buf, sizeof(buf), 0)) == 0) {
 			return 0;
@@ -287,7 +304,7 @@ static int procevent_monitor(const int sock, pid_t mypid) {
 					}
 					sprintf(lineptr, " exec");
 					break;
-					
+
 				case PROC_EVENT_EXIT:
 					if (proc_ev->event_data.exit.process_pid !=
 					    proc_ev->event_data.exit.process_tgid)
@@ -300,7 +317,7 @@ static int procevent_monitor(const int sock, pid_t mypid) {
 					remove_pid = 1;
 					sprintf(lineptr, " exit");
 					break;
-					
+
 				case PROC_EVENT_UID:
 					pid = proc_ev->event_data.id.process_tgid;
 #ifdef DEBUG_PRCTL
@@ -346,11 +363,11 @@ static int procevent_monitor(const int sock, pid_t mypid) {
 					continue;
 				}
 			}
-				
+
 			lineptr += strlen(lineptr);
 			sprintf(lineptr, " %u", pid);
 			lineptr += strlen(lineptr);
-			
+
 			char *user = pids[pid].user;
 			if (!user)
 				user = pid_get_user_name(pids[pid].uid);
@@ -359,7 +376,7 @@ static int procevent_monitor(const int sock, pid_t mypid) {
 				sprintf(lineptr, " (%s)", user);
 				lineptr += strlen(lineptr);
 			}
-			
+
 
 			int sandbox_closed = 0; // exit sandbox flag
 			char *cmd = pids[pid].cmd;
@@ -392,11 +409,11 @@ static int procevent_monitor(const int sock, pid_t mypid) {
 				lineptr += strlen(lineptr);
 			}
 			(void) lineptr;
-			
+
 			// print the event
-			printf("%s", line);			
+			printf("%s", line);
 			fflush(0);
-			
+
 			// unflag pid for exit events
 			if (remove_pid) {
 				if (pids[pid].user)
@@ -416,15 +433,15 @@ static int procevent_monitor(const int sock, pid_t mypid) {
 				else
 					printf("\tchild %u\n", child);
 			}
-			
+
 			// on uid events the uid is changing
 			if (proc_ev->what == PROC_EVENT_UID) {
 				if (pids[pid].user)
 					free(pids[pid].user);
 				pids[pid].user = 0;
-				pids[pid].uid = pid_get_uid(pid); 
+				pids[pid].uid = pid_get_uid(pid);
 			}
-			
+
 			if (sandbox_closed)
 				exit(0);
 		}
@@ -432,16 +449,6 @@ static int procevent_monitor(const int sock, pid_t mypid) {
 	return 0;
 }
 
-static void procevent_print_pids(void) {
-	// print files
-	int i;
-	for (i = 0; i < max_pids; i++) {
-		if (pids[i].level == 1)
-			pid_print_tree(i, 0, 1);
-	}
-	printf("\n");
-}
-
 void procevent(pid_t pid) {
 	// need to be root for this
 	if (getuid() != 0) {
@@ -449,10 +456,6 @@ void procevent(pid_t pid) {
 		exit(1);
 	}
 
-	// read and print sandboxed processes
-	pid_read(pid);
-	procevent_print_pids();
-
 	// monitor using netlink
 	int sock = procevent_netlink_setup();
 	if (sock < 0) {
