@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2016 netblue30 (netblue30@yahoo.com)
+ * Copyright (C) 2014-2017 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -47,7 +47,7 @@ static void log_rotate(const char *fname) {
 	strcpy(name1, fname);
 	strcpy(name2, fname);
 	fflush(0);
-	
+
 	// delete filename.5
 	sprintf(name1 + index, ".5");
 	if (stat(name1, &s) == 0) {
@@ -55,7 +55,7 @@ static void log_rotate(const char *fname) {
 		if (rv == -1)
 			perror("unlink");
 	}
-	
+
 	// move files 1 to 4 down one position
 	sprintf(name2 + index, ".4");
 	if (stat(name2, &s) == 0) {
@@ -96,14 +96,14 @@ static void log_rotate(const char *fname) {
 		if (rv == -1)
 			perror("rename");
 	}
-	
+
 	free(name1);
 	free(name2);
 }
 
 static void log_write(const unsigned char *str, int len, const char *fname) {
 	assert(fname);
-	
+
 	if (out_fp == NULL) {
 		out_fp = fopen(fname, "w");
 		if (!out_fp) {
@@ -112,7 +112,7 @@ static void log_write(const unsigned char *str, int len, const char *fname) {
 		}
 		out_cnt = 0;
 	}
-	
+
 	// rotate files
 	out_cnt += len;
 	if (out_cnt >= out_max) {
@@ -127,9 +127,10 @@ static void log_write(const unsigned char *str, int len, const char *fname) {
 			exit(1);
 		}
 		out_cnt = len;
-	}				
-		
-	fwrite(str, len, 1, out_fp);	
+	}
+
+	int rv = fwrite(str, len, 1, out_fp);
+	(void) rv;
 	fflush(0);
 }
 
@@ -139,7 +140,7 @@ static int is_dir(const char *fname) {
 	assert(fname);
 	if (*fname == '\0')
 		return 0;
-	
+
 	// if fname doesn't end in '/', add one
 	int rv;
 	struct stat s;
@@ -150,14 +151,14 @@ static int is_dir(const char *fname) {
 		if (asprintf(&tmp, "%s/", fname) == -1) {
 			fprintf(stderr, "Error: cannot allocate memory, %s:%d\n", __FILE__, __LINE__);
 			exit(1);
-		}		
+		}
 		rv = stat(tmp, &s);
 		free(tmp);
 	}
-	
+
 	if (rv == -1)
 		return 0;
-		
+
 	if (S_ISDIR(s.st_mode))
 		return 1;
 
@@ -179,10 +180,6 @@ static int is_link(const char *fname) {
 	return 0;
 }
 
-
-
-
-
 static void usage(void) {
 	printf("Usage: ftee filename\n");
 }
@@ -193,37 +190,33 @@ int main(int argc, char **argv) {
 		usage();
 		exit(1);
 	}
+	if (strcmp(argv[1], "--help") == 0) {
+		usage();
+		return 0;
+	}
 	char *fname = argv[1];
 
 
 	// do not accept directories, links, and files with ".."
-	if (strstr(fname, "..") || is_link(fname) || is_dir(fname)) {
-		fprintf(stderr, "Error: invalid output file. Links, directories and files with \"..\" are not allowed.\n");
-		exit(1);
-	}
-	
+	if (strstr(fname, "..") || is_link(fname) || is_dir(fname))
+		goto errexit;
+
 	struct stat s;
 	if (stat(fname, &s) == 0) {
 		// check permissions
-		if (s.st_uid != getuid() || s.st_gid != getgid()) {
-			fprintf(stderr, "Error: the output file needs to be owned by the current user.\n");
-			exit(1);
-		}
-		
+		if (s.st_uid != getuid() || s.st_gid != getgid())
+			goto errexit;
+
 		// check hard links
-		if (s.st_nlink != 1) {
-			fprintf(stderr, "Error: no hard links allowed.\n");
-			exit(1);
-		}
+		if (s.st_nlink != 1)
+			goto errexit;
 	}
 
 	// check if we can append to this file
 	/* coverity[toctou] */
 	FILE *fp = fopen(fname, "a");
-	if (!fp) {
-		fprintf(stderr, "Error: cannot open output file %s\n", fname);
-		exit(1);
-	}
+	if (!fp)
+		goto errexit;
 	fclose(fp);
 
 
@@ -237,11 +230,16 @@ int main(int argc, char **argv) {
 			continue;
 		if (n <= 0)
 			break;
-		
-		fwrite(buf, n, 1, stdout);
+
+		int rv = fwrite(buf, n, 1, stdout);
+		(void) rv;
 		log_write(buf, n, fname);
 	}
-	
+
 	log_close();
 	return 0;
+
+errexit:
+	fprintf(stderr, "Error ftee: invalid output file.\n");
+	return 1;
 }
