@@ -282,3 +282,42 @@ int pid_hidepid(void) {
 	fclose(fp);
 	return 0;
 }
+
+//**************************
+// time trace based on getticks function
+//**************************
+static int tt_not_implemented = 0; // not implemented for the current architecture
+static unsigned long long tt_1ms = 0;
+static unsigned long long tt = 0;	// start time
+
+void timetrace_start(void) {
+	if (tt_not_implemented)
+		return;
+	unsigned long long t1 = getticks();
+	if (t1 == 0) {
+		tt_not_implemented = 1;
+		return;
+	}
+
+	if (tt_1ms == 0) {
+		usleep(1000);	// sleep 1 ms
+		unsigned long long t2 = getticks();
+		tt_1ms = t2 - t1;
+		if (tt_1ms == 0) {
+			tt_not_implemented = 1;
+			return;
+		}
+	}
+
+	tt = getticks();
+}
+
+float timetrace_end(void) {
+	if (tt_not_implemented)
+		return 0;
+
+	unsigned long long delta = getticks() - tt;
+	assert(tt_1ms);
+
+	return (float) delta / (float) tt_1ms;
+}
