@@ -1,6 +1,6 @@
 #!/bin/bash
 # This file is part of Firejail project
-# Copyright (C) 2014-2016 Firejail Authors
+# Copyright (C) 2014-2017 Firejail Authors
 # License GPL v2
 
 export MALLOC_CHECK_=3
@@ -24,12 +24,11 @@ else
 	echo "TESTING SKIP: transmission-gtk not found"
 fi
 
-which icedove
+which thunderbird
 if [ "$?" -eq 0 ];
 then
-	echo "TESTING: icedove x11 xorg"
-	./icedove.exp
+	echo "TESTING: thunderbird x11 xorg"
+	./thunderbird.exp
 else
-	echo "TESTING SKIP: icedove not found"
+	echo "TESTING SKIP: thunderbird not found"
 fi
-
