@@ -1,11 +1,38 @@
 #!/bin/bash
 # This file is part of Firejail project
-# Copyright (C) 2014-2016 Firejail Authors
+# Copyright (C) 2014-2017 Firejail Authors
 # License GPL v2
 
 export MALLOC_CHECK_=3
 export MALLOC_PERTURB_=$(($RANDOM % 255 + 1))
 
+echo "TESTING: no x11 (test/apps-x11/x11-none.exp)"
+./x11-none.exp
+
+
+which xterm
+if [ "$?" -eq 0 ];
+then
+	echo "TESTING: xterm x11 xorg"
+	./xterm-xorg.exp
+
+	which xpra
+	if [ "$?" -eq 0 ];
+	then
+	echo "TESTING: xterm x11 xpra"
+	./xterm-xpra.exp
+	fi
+
+	which Xephyr
+	if [ "$?" -eq 0 ];
+	then
+	echo "TESTING: xterm x11 xephyr"
+	./xterm-xephyr.exp
+	fi
+else
+	echo "TESTING SKIP: xterm not found"
+fi
+
 # check xpra/xephyr
 which xpra
 if [ "$?" -eq 0 ];
@@ -23,15 +50,6 @@ else
 	fi
 fi
 
-which xterm
-if [ "$?" -eq 0 ];
-then
-	echo "TESTING: xterm x11"
-	./xterm.exp
-else
-	echo "TESTING SKIP: xterm not found"
-fi
-
 which firefox
 if [ "$?" -eq 0 ];
 then
@@ -59,12 +77,11 @@ else
 	echo "TESTING SKIP: transmission-gtk not found"
 fi
 
-which icedove
+which thunderbird
 if [ "$?" -eq 0 ];
 then
-	echo "TESTING: icedove x11"
-	./icedove.exp
+	echo "TESTING: thunderbird x11"
+	./thunderbird.exp
 else
-	echo "TESTING SKIP: icedove not found"
+	echo "TESTING SKIP: thunderbird not found"
 fi
-
